@@ -257,11 +257,6 @@ class NovaImageList(task_manager.Task):
         return client.nova_client.images.list()
 
 
-class ImageSnapshotCreate(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.servers.create_image(**self.args)
-
-
 class VolumeTypeList(task_manager.Task):
     def main(self, client):
         return client.cinder_client.volume_types.list()
@@ -294,11 +289,6 @@ class VolumeDelete(task_manager.Task):
         client.cinder_client.volumes.delete(**self.args)
 
 
-class VolumeList(task_manager.Task):
-    def main(self, client):
-        return client.cinder_client.volumes.list()
-
-
 class VolumeDetach(task_manager.Task):
     def main(self, client):
         client.nova_client.volumes.delete_server_volume(**self.args)
@@ -374,36 +364,6 @@ class NeutronSecurityGroupRuleDelete(task_manager.Task):
         return client.neutron_client.delete_security_group_rule(**self.args)
 
 
-class NovaSecurityGroupList(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.security_groups.list(**self.args)
-
-
-class NovaSecurityGroupCreate(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.security_groups.create(**self.args)
-
-
-class NovaSecurityGroupDelete(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.security_groups.delete(**self.args)
-
-
-class NovaSecurityGroupUpdate(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.security_groups.update(**self.args)
-
-
-class NovaSecurityGroupRuleCreate(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.security_group_rules.create(**self.args)
-
-
-class NovaSecurityGroupRuleDelete(task_manager.Task):
-    def main(self, client):
-        return client.nova_client.security_group_rules.delete(**self.args)
-
-
 class NeutronFloatingIPList(task_manager.Task):
     def main(self, client):
         return client.neutron_client.list_floatingips(**self.args)
