@@ -1,5 +1,4 @@
 #!/bin/sh
-# -*- coding: utf-8 -*-
 
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -20,6 +19,14 @@ sudo chown -R jenkins:stack $SHADE_DIR
 
 CLOUDS_YAML=/etc/openstack/clouds.yaml
 
+if [ ! -e ${CLOUDS_YAML} ]
+then
+    # stable/liberty had clouds.yaml in the home/base directory
+    sudo mkdir -p /etc/openstack
+    sudo cp $BASE/new/.config/openstack/clouds.yaml ${CLOUDS_YAML}
+    sudo chown -R jenkins:stack /etc/openstack
+fi
+
 # Devstack runs both keystone v2 and v3. An environment variable is set
 # within the shade keystone v2 job that tells us which version we should
 # test against.
@@ -29,10 +36,16 @@ then
     sudo sed -ie '/^.*domain_id.*$/d' $CLOUDS_YAML
 fi
 
+if [ "x$1" = "xtips" ] ; then
+    tox_env=functional-tips
+else
+    tox_env=functional
+fi
 echo "Running shade functional test suite"
 set +e
-sudo -E -H -u jenkins tox -efunctional
+sudo -E -H -u jenkins tox -e$tox_env
 EXIT_CODE=$?
+sudo testr last --subunit > $WORKSPACE/tempest.subunit
 set -e
 
 exit $EXIT_CODE
