@@ -17,6 +17,7 @@ import collections
 import time
 import uuid
 
+from distutils import version as du_version
 import fixtures
 import mock
 import os
@@ -416,6 +417,16 @@ class RequestsMockTestCase(BaseTestCase):
         self.adapter = self.useFixture(rm_fixture.Fixture())
         self.calls = []
         self._uri_registry.clear()
+
+        # occ > 1.26.0 fixes keystoneclient construction. Unfortunately, it
+        # breaks our mocking of what keystoneclient does here. Since we're
+        # close to just getting rid of ksc anyway, just put in a version match
+        occ_version = du_version.StrictVersion(occ.__version__)
+        if occ_version > du_version.StrictVersion('1.26.0'):
+            endpoint_uri = 'https://identity.example.com/v2.0'
+        else:
+            endpoint_uri = 'https://identity.example.com/'
+
         self.__do_register_uris([
             dict(method='GET', uri='https://identity.example.com/',
                  text=open(self.discovery_json, 'r').read()),
@@ -423,7 +434,7 @@ class RequestsMockTestCase(BaseTestCase):
                  text=open(os.path.join(
                      self.fixtures_directory, 'catalog-v2.json'), 'r').read()
                  ),
-            dict(method='GET', uri='https://identity.example.com/',
+            dict(method='GET', uri=endpoint_uri,
                  text=open(self.discovery_json, 'r').read()),
             dict(method='GET', uri='https://identity.example.com/',
                  text=open(self.discovery_json, 'r').read())
@@ -550,7 +561,7 @@ class RequestsMockTestCase(BaseTestCase):
                 mock_method, mock_uri, params['response_list'],
                 **params['kw_params'])
 
-    def assert_calls(self, stop_after=None):
+    def assert_calls(self, stop_after=None, do_count=True):
         for (x, (call, history)) in enumerate(
                 zip(self.calls, self.adapter.request_history)):
             if stop_after and x > stop_after:
@@ -571,4 +582,6 @@ class RequestsMockTestCase(BaseTestCase):
                     self.assertEqual(
                         value, history.headers[key],
                         'header mismatch in call {index}'.format(index=x))
-        self.assertEqual(len(self.calls), len(self.adapter.request_history))
+        if do_count:
+            self.assertEqual(
+                len(self.calls), len(self.adapter.request_history))
